Summary: GNU libc
Name: glibc
Version: 2.1
Release: 2
Group: Development/Libraries/Libc
Copyright: LGPL
Packager: Hao Li <hli@wag.caltech.edu>
Source0: ftp://ftp.gnu.org/gnu/glibc/glibc-%{version}.tar.gz
Source1: ftp://ftp.gnu.org/gnu/glibc/glibc-crypt-%{version}.tar.gz
Source2: ftp://ftp.gnu.org/gnu/glibc/glibc-linuxthreads-%{version}.tar.gz
Source3: glibc-2.1-nsswitch.conf
Patch0:  glibc-2.1-rhvi.patch
Patch1:  glibc-2.1-noversion.patch
BuildRoot: /var/tmp/%{name}-root
Autoreq: false

%description
Contains the standard libraries that are used by multiple programs on
the system. In order to save disk space and memory, as well as to
ease upgrades, common system code is kept in one place and shared between
programs. This package contains the most important sets of shared libraries,
the standard C library and the standard math library. Without these, a
Linux system will not function. It also contains national language (locale)
support and timezone databases.


%package devel
Summary: Additional libraries required to compile
Group: Development/Libraries/Libc
Requires: glibc = %{version}, kernel-headers

%description devel
To develop programs which use the standard C libraries (which nearly all
programs do), the system needs to have these standard header files and object
files available for creating the executables.


#%package profile
#Summary: glibc with profiling support
#Group: Development/Libraries/Libc
#
#%description profile
#When programs are being profiled used gprof, they must use these libraries
#instrad of the standard C libraries for gprof to be able to profile
#them correctly.
#
#
#%package debug
#Summary: glibc with debugging information
#Group: Development/Libraries/Libc
#
#%description debug
#These libraries have the debugging information debuggers use for tracing
#the execution of programs. These are only needed when the shared libraries
#themselves are being debugged -- they are not needed to debug programs which
#use them.


%prep
%setup -q -a 1 -a 2
%patch0 -p1
%patch1 -p1


%build
CFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=/usr --enable-add-ons
make

# Remake info files with --no-split
cd manual
make clean info dvi MAKEINFO="makeinfo --no-split"
dvips -t letter -o libc.ps libc.dvi
gzip -9f libc.ps


%install
rm -rf $RPM_BUILD_ROOT
make install_root=$RPM_BUILD_ROOT install

# install full set of locale data
make -C localedata install_root=$RPM_BUILD_ROOT install-locales

# install man pages for linuxthreads
make -C linuxthreads/man
mkdir -p $RPM_BUILD_ROOT/usr/man/man3
install -m644 linuxthreads/man/*.3thr $RPM_BUILD_ROOT/usr/man/man3

# gzip info pages
gzip -9f $RPM_BUILD_ROOT/usr/info/libc.info*
rm -f $RPM_BUILD_ROOT/usr/info/dir

# Timezone. I'll keep the default Factory time zone in RPM
#   /etc/localtime -> ../usr/share/zoneinfo/Factory
# After installation in California US this should be customized to be
#   /etc/localtime -> ../usr/share/zoneinfo/US/Pacific

# nsswitch.conf for glibc-2.1. The default form is the same as glibc-2.0.7.
install -m644 %{SOURCE3} $RPM_BUILD_ROOT/etc/nsswitch.conf

# This is for ncsd - in glibc-2.1 but not glibc-2.0.7
install -m644 nscd/nscd.conf $RPM_BUILD_ROOT/etc
mkdir -p $RPM_BUILD_ROOT/etc/rc.d/init.d
install -m755 nscd/nscd.init $RPM_BUILD_ROOT/etc/rc.d/init.d/nscd

# The database support
mkdir -p $RPM_BUILD_ROOT/var/db
install -m 644 nss/db-Makefile $RPM_BUILD_ROOT/var/db/Makefile

# We don't need this. Besides util-linux already provides it.
rm -f $RPM_BUILD_ROOT/sbin/sln

# strip the remaining binaries
strip $RPM_BUILD_ROOT/{sbin,usr/bin,usr/sbin}/* || :

# Now prepare for %doc
mkdir -p rpm_doc/{crypt,linuxthreads}
cp -pr crypt/{COPYING.LIB,ChangeLog,README,README.ufc-crypt,examples} \
				rpm_doc/crypt
cp -pr linuxthreads/{ChangeLog,Changes,Examples,FAQ.html,LICENSE,README,README.Xfree3.2} \
				rpm_doc/linuxthreads
cp -p  db2/README		rpm_doc/README.db2
cp -p  db2/mutex/README		rpm_doc/README.db2.mutex
cp -p  hesiod/README.hesiod	rpm_doc/README.hesiod
cp -p  localedata/README	rpm_doc/README.localedata
cp -p  login/README.utmpd	rpm_doc/README.utmpd
cp -p  timezone/README		rpm_doc/README.timezone


%post
/sbin/ldconfig
/sbin/chkconfig --add nscd

%preun
if [ $1 = 0 ]; then
    /sbin/chkconfig --del nscd
fi

%postun
/sbin/ldconfig


%post devel
/sbin/install-info /usr/info/libc.info.gz /usr/info/dir

%preun devel
if [ $1 = 0 ]; then
    /sbin/install-info --delete /usr/info/libc.info.gz /usr/info/dir
fi


%files
%defattr(-,root,root)
%doc BUGS CONFORMANCE COPYING COPYING.LIB ChangeLog* FAQ INSTALL INTERFACE
%doc NEWS NOTES PROJECTS README README.libm rpm_doc/*
%config /etc/localtime
%config /etc/nscd.conf
%config /etc/nsswitch.conf
%config /etc/rc.d/init.d/nscd
%config /etc/rpc
/lib/*
#/sbin/*
/usr/bin/*
/usr/sbin/*
/usr/share/*
/var/db


%files devel
%defattr(-,root,root)
%doc manual/libc.dvi manual/libc.ps.gz
/usr/include/*
/usr/info/*
/usr/lib/*
/usr/libexec/*
/usr/man/man*/*


%clean
rm -rf $RPM_BUILD_ROOT


%changelog
* Mon Mar  8 1999 Hao Li <hli@wag.caltech.edu>
- glibc-2.1-2. Some refinements based on RH Rawhide RPM.

* Wed Feb 10 1999 Hao Li <hli@wag.caltech.edu>
- glibc-2.1-1.
- debug and profile sub-RPM is combined into devel RPM.
